@@ -1,6 +1,6 @@
 #include <stdio.h>
 
-static char version[] = "0.6.4 beta";
+static char version[] = "0.8.9 beta";
 
 // 関数プロトタイプ
 void help(void);
@@ -45,20 +45,35 @@ void help()
 	puts(" -i         ファイルを上書きする前に確認する。");
 	puts("            (例 : snowcp -i source dest)");
 	puts("");
+	puts(" -I         -iオプションを無効にする。");
+	puts("            (例 : snowcp -I source dest)");
+	puts("");
 	puts(" -l         コンペアのログを保存する。");
 	puts("            -cオプションのログは保存しない。");
 	puts("            (例 : snowcp -1 2 -l source dest)");
 	puts("");
+	puts(" -L         -lオプションを無効にする。");
+	puts("            (例 : snowcp -L source dest)");
+	puts("");
 	puts(" -m         ファイルを移動する。");
 	puts("            (例 : snowcp -m source dest)");
 	puts("");
+	puts(" -M         -mオプションを無効にする。");
+	puts("            (例 : snowcp -M source dest)");
+	puts("");
 	puts(" -o         設定を保存する。");
 	puts("            (例 : snowcp -o)");
 	puts("");
+	puts(" -t MODE    スレッドモードを指定する。");
+	puts("            MODEが1の場合は常に同一ドライブモード、");
+	puts("            2の場合は常に別ドライブモード、");
+	puts("            0の場合は自動判別モードで動作する。");
+	puts("            (例 : snowcp -t 1 source dest)");
+	puts("");
 	puts(" -v         コピー中のファイル名を表示する。");
 	puts("            (例 : snowcp -v source dest)");
 	puts("");
-	puts(" -w MODE    ファイルを上書きする。");
+	puts(" -w MODE    上書きモードを指定する。");
 	puts("            MODEが1の場合はサイズか日付が異なる時、");
 	puts("            2の場合は日付が新しい時、");
 	puts("            3の場合は常に上書きする。");
@@ -66,4 +81,8 @@ void help()
 	puts("            (例 : snowcp -w 3 source dest)");
 	puts("");
 	puts("注 : オプションは後に入力した方が優先される。例えば snowcp -iw とした場合、-wオプションが有効になる。");
+	puts("");
+	puts("注 : -iオプションを付けた場合、-i -w 3 と同義になる (サイズの比較等は行われない)。");
+	puts("");
+	puts("注 : スレッドモードは引数として与えたファイルを基準とするため、サブフォルダにファイルシステムをマウントしている場合は、正常に動作しない。");
 }
