@@ -4,15 +4,14 @@
 */
 #define _GNU_SOURCE
 
+#include "ch_time_and_mod.h" // inline
+#include "compare_hash.h"
+#include "compare_memcmp.h"
+#include "print_error.h" // inline
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
 
-#include "ch_time_and_mod.h"
-#include "compare_hash.h"
-#include "compare_memcmp.h"
-#include "print_error.h"
-
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,11 +26,34 @@
 #define TO_OPEN \
 {\
 	errno = 0;\
-	if((rwd.ito = open(cpinfo->to, O_CREAT | O_WRONLY, S_IRUSR | S_IWUSR)) == -1)\
+	if((ito = open(cpinfo->to, O_CREAT | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR)) == -1)\
 	{\
-		if(errno > 0)\
+		switch(errno)\
 		{\
+		case ELOOP:\
+			errno = 0;\
+\
+			if(unlink(cpinfo->to) == -1)\
+			{\
+				print_error("unlink", __FILE__, __LINE__, cpdd);\
+			}\
+			else \
+			{\
+				if((ito = open(cpinfo->to, O_CREAT | O_NOFOLLOW | O_WRONLY, S_IRUSR | S_IWUSR)) == -1)\
+				{\
+					print_error("open", __FILE__, __LINE__, cpdd);\
+				}\
+				else \
+				{\
+					to_open = true;\
+					cpdd->mk_file_count++;\
+				}\
+			}\
+			break;\
+\
+		default:\
 			print_error("open", __FILE__, __LINE__, cpdd);\
+			break;\
 		}\
 	}\
 	else \
@@ -41,46 +63,74 @@
 	}\
 }
 
-typedef struct read_write_data
-{
-	void *buf[2];
-	off_t from_size_local;
-	off_t written_size[2];
-	off_t next_write_size[2];
-	off_t total_read_local;
-	off_t total_write_local;
-	off_t total_read_error; // スレッド用
-	off_t total_write_error; // スレッド用
-	off_t buffer_size_local;
-	long psize;
-	int ifrom;
-	int ito;
-	int rbuf_num;
-	int wbuf_num;
-} RWD;
+#define HASH_CHECK \
+{\
+	if((from_open == true) && (to_open == true))\
+	{\
+		compare_hash(oparg, cpinfo, sdir, cpdd);\
+	}\
+	else if(cpinfo->skip == false)\
+	{\
+		fprintf(stderr, "ファイルのオープンに失敗しているため、コンペアをスキップします\n");\
+		fprintf(stderr, "from : %s\n", cpinfo->from);\
+		fprintf(stderr, "to   : %s\n", cpinfo->to);\
+	}\
+}
+
+static void *buf[2];
+static off_t from_size_local;
+static off_t written_size[2];
+static off_t next_write_size[2];
+static off_t total_read_local;
+static off_t total_write_local;
+static off_t total_read_error; // スレッド用
+static off_t total_write_error; // スレッド用
+static off_t buffer_size_local;
+static int ifrom;
+static int ito;
+static int rbuf_num;
+static int wbuf_num;
+static long psize = 0;
+static _Bool from_open;
+static _Bool from_stat;
+static _Bool to_open;
 
 // ※注意。グローバル変数。
 char *write_now;
 
 // 関数プロトタイプ
 _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
-static void * read_thread(void *read_t);
-static void * write_thread(void *write_t);
+static void * read_thread(void *unknown);
+static void * write_thread(void *unknown);
 
 /*******************************************************************************
 *******************************************************************************/
 _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 {
-	_Bool from_stat = false;
-	_Bool from_open = false;
-	_Bool to_open = false;
 	struct stat stat_buf;
-	RWD rwd;
-	rwd.from_size_local = 0;
-	rwd.total_read_local = 0;
-	rwd.total_write_local = 0;
-	rwd.total_read_error = 0;
-	rwd.total_write_error = 0;
+
+	from_stat = false;
+	from_open = false;
+	to_open = false;
+	from_size_local = 0;
+	written_size[0] = 0;
+	written_size[1] = 0;
+	next_write_size[0] = 0;
+	next_write_size[1] = 0;
+	total_read_local = 0;
+	total_write_local = 0;
+	total_read_error = 0;
+	total_write_error = 0;
+	buffer_size_local = 0;
+	ifrom = 0;
+	ito = 0;
+	rbuf_num = 0;
+	wbuf_num = 0;
+
+	if(psize == 0)
+	{
+		psize = sysconf(_SC_PAGESIZE);
+	}
 
 	cpinfo->from_size = 0;
 	cpinfo->to_size = 0;
@@ -89,7 +139,7 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	write_now = cpinfo->to;
 
 	errno = 0;
-	if((rwd.ifrom = open(cpinfo->from, O_RDONLY | O_NOATIME)) == -1)
+	if((ifrom = open(cpinfo->from, O_RDONLY | O_NOATIME)) == -1)
 	{
 		print_error("open", __FILE__, __LINE__, cpdd);
 	}
@@ -98,17 +148,17 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		from_open = true;
 
 		errno = 0;
-		if(fstat(rwd.ifrom, &stat_buf) == -1)
+		if(fstat(ifrom, &stat_buf) == -1)
 		{
 			print_error("fstat", __FILE__, __LINE__, cpdd);
 		}
 		else
 		{
 			from_stat = true;
-			rwd.from_size_local = stat_buf.st_size;
+			from_size_local = stat_buf.st_size;
 		}
 
-		if((cpinfo->file_test == false) || (oparg->write_mode == 3))
+		if((cpinfo->file_test == false) || (oparg->WRITE_MODE == OVERWRITE))
 		{
 			TO_OPEN
 		}
@@ -128,9 +178,8 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 			}
 			else
 			{
-				switch(oparg->write_mode)
+				if(oparg->WRITE_MODE == SIZE_OR_TIME)
 				{
-				case 1:
 					if((stat_buf.st_size != stat_to.st_size) || (stat_buf.st_mtime != stat_to.st_mtime))
 					{
 						TO_OPEN
@@ -139,9 +188,9 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					{
 						cpinfo->skip = true;
 					}
-					break;
-
-				case 2:
+				}
+				else
+				{
 					if((stat_buf.st_mtime > stat_to.st_mtime))
 					{
 						TO_OPEN
@@ -150,13 +199,12 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					{
 						cpinfo->skip = true;
 					}
-					break;
 				}
 			}
 		}
 		else
 		{
-			print_error("read_write", __FILE__, __LINE__, cpdd);
+			print_error(__func__, __FILE__, __LINE__, cpdd);
 			fprintf(stderr, "%s をコピーできません\n", cpinfo->from);
 		}
 	}
@@ -179,23 +227,25 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	 * sparse file化とは違うらしい？
 	 * ext4以外の、それをサポートしていないファイルシステムだとかなり遅くなる様子。
 	*/
-	if((rwd.from_size_local > 0) && (to_open == true))
+	if((from_size_local > 0) && (to_open == true))
 	{
+		char *tofs_tmp = cpinfo->tofs;
+
 		if(
-		(cpinfo->tofs != NULL) &&
-		(cpinfo->tofs[0] == 'e') &&
-		(cpinfo->tofs[1] == 'x') &&
-		(cpinfo->tofs[2] == 't') &&
-		(cpinfo->tofs[3] == '4')
+		(tofs_tmp != NULL) &&
+		(tofs_tmp[0] == 'e') &&
+		(tofs_tmp[1] == 'x') &&
+		(tofs_tmp[2] == 't') &&
+		(tofs_tmp[3] == '4')
 		)
 		{
 			errno = 0;
-			if(posix_fallocate(rwd.ito, 0, rwd.from_size_local) != 0)
+			if(posix_fallocate(ito, 0, from_size_local) != 0)
 			{
 				print_error("posix_fallocate", __FILE__, __LINE__, cpdd);
 
 				errno = 0;
-				if(ftruncate(rwd.ito, rwd.from_size_local) == -1)
+				if(ftruncate(ito, from_size_local) == -1)
 				{
 					print_error("ftruncate", __FILE__, __LINE__, cpdd);
 				}
@@ -204,7 +254,7 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		else
 		{
 			errno = 0;
-			if(pwrite(rwd.ito, "", 1, rwd.from_size_local - 1) == -1)
+			if(pwrite(ito, "", 1, from_size_local - 1) == -1)
 			{
 				print_error("pwrite", __FILE__, __LINE__, cpdd);
 			}
@@ -212,44 +262,44 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 	}
 
 	// コピー開始
-	if((rwd.from_size_local > 0) && (to_open == true))
+	if((from_size_local > 0) && (to_open == true))
 	{
 		if(oparg->V == VERBOS)
 		{
 			printf("%s -> %s\n", cpinfo->from, cpinfo->to);
 		}
 
-		if(oparg->buffer_size >= rwd.from_size_local)
+		if(oparg->buffer_size >= from_size_local)
 		{
 			errno = 0;
-			rwd.buf[0] = mmap(NULL, rwd.from_size_local, PROT_READ, MAP_PRIVATE, rwd.ifrom, 0);
+			buf[0] = mmap(NULL, from_size_local, PROT_READ, MAP_PRIVATE, ifrom, 0);
 
-			if(rwd.buf[0] != MAP_FAILED)
+			if(buf[0] != MAP_FAILED)
 			{
-				rwd.total_read_local = rwd.from_size_local;
+				total_read_local = from_size_local;
 				errno = 0;
-				if(madvise(rwd.buf[0], rwd.from_size_local, MADV_SEQUENTIAL) != 0)
+				if(madvise(buf[0], from_size_local, MADV_SEQUENTIAL) != 0)
 				{
 					print_error("madvise", __FILE__, __LINE__, cpdd);
 				}
 
-				char *tmp = rwd.buf[0];
-				const char * const endp = tmp + rwd.from_size_local;
+				char *tmp = buf[0];
+				const char * const endp = tmp + from_size_local;
 
 				while(tmp < endp)
 				{
 					errno = 0;
-					if((rwd.written_size[0] = write(rwd.ito, tmp, endp - tmp)) == -1)
+					if((written_size[0] = write(ito, tmp, endp - tmp)) == -1)
 					{
 						print_error("write", __FILE__, __LINE__, cpdd);
 						break;
 					}
-					tmp += rwd.written_size[0];
-					rwd.total_write_local += rwd.written_size[0];
+					tmp += written_size[0];
+					total_write_local += written_size[0];
 				}
 
 				errno = 0;
-				if(munmap(rwd.buf[0], rwd.from_size_local) != 0)
+				if(munmap(buf[0], from_size_local) != 0)
 				{
 					print_error("munmap", __FILE__, __LINE__, cpdd);
 				}
@@ -261,38 +311,36 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		}
 		else if(cpinfo->copy_mode == DIFFERENT)
 		{
-			rwd.psize = sysconf(_SC_PAGESIZE);
+			buffer_size_local = oparg->buffer_size_thread;
+			rbuf_num = 0;
 
-			// バッファを二つ使用するので
-			rwd.buffer_size_local = oparg->buffer_size / 2;
-			rwd.rbuf_num = 0;
 			pthread_t t1;
 			pthread_t t2;
-			pthread_create(&t1, NULL, read_thread, (void *)&rwd);
+			pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
 			pthread_join(t1, NULL);
 
 			for(;;)
 			{
-				rwd.rbuf_num = 1;
-				rwd.wbuf_num = 0;
-				pthread_create(&t1, NULL, read_thread, (void *)&rwd);
-				pthread_create(&t2, NULL, write_thread, (void *)&rwd);
+				rbuf_num = 1;
+				wbuf_num = 0;
+				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+				pthread_create(&t2, NULL, write_thread, (void *)&wbuf_num);
 				pthread_join(t1, NULL);
 				pthread_join(t2, NULL);
 
-				if((rwd.from_size_local <= rwd.total_write_local) || (rwd.written_size[0] <= 0))
+				if((from_size_local <= total_write_local) || (written_size[wbuf_num] <= 0))
 				{
 					break;
 				}
 
-				rwd.rbuf_num = 0;
-				rwd.wbuf_num = 1;
-				pthread_create(&t1, NULL, read_thread, (void *)&rwd);
-				pthread_create(&t2, NULL, write_thread, (void *)&rwd);
+				rbuf_num = 0;
+				wbuf_num = 1;
+				pthread_create(&t1, NULL, read_thread, (void *)&rbuf_num);
+				pthread_create(&t2, NULL, write_thread, (void *)&wbuf_num);
 				pthread_join(t1, NULL);
 				pthread_join(t2, NULL);
 
-				if((rwd.from_size_local <= rwd.total_write_local) || (rwd.written_size[1] <= 0))
+				if((from_size_local <= total_write_local) || (written_size[wbuf_num] <= 0))
 				{
 					break;
 				}
@@ -300,11 +348,9 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 		}
 		else
 		{
-			rwd.psize = sysconf(_SC_PAGESIZE);
-
 			for(;;)
 			{
-				off_t read_size = rwd.from_size_local - rwd.total_read_local;
+				off_t read_size = from_size_local - total_read_local;
 
 				if(read_size >= oparg->buffer_size)
 				{
@@ -312,7 +358,7 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				}
 				else
 				{
-					off_t tmp = read_size % rwd.psize;
+					off_t tmp = read_size % psize;
 
 					if(tmp != read_size)
 					{
@@ -321,42 +367,42 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 				}
 
 				errno = 0;
-				rwd.buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, rwd.ifrom, rwd.total_read_local);
+				buf[0] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, ifrom, total_read_local);
 
-				if(rwd.buf[0] != MAP_FAILED)
+				if(buf[0] != MAP_FAILED)
 				{
-					rwd.total_read_local += read_size;
+					total_read_local += read_size;
 
 					errno = 0;
-					if(madvise(rwd.buf[0], read_size, MADV_SEQUENTIAL) != 0)
+					if(madvise(buf[0], read_size, MADV_SEQUENTIAL) != 0)
 					{
 						print_error("madvise", __FILE__, __LINE__, cpdd);
 					}
 
-					char *tmp = rwd.buf[0];
+					char *tmp = buf[0];
 					const char * const endp = tmp + read_size;
 
 					while(tmp < endp)
 					{
 						errno = 0;
-						if((rwd.written_size[0] = write(rwd.ito, tmp, endp - tmp)) == -1)
+						if((written_size[0] = write(ito, tmp, endp - tmp)) == -1)
 						{
 							print_error("write", __FILE__, __LINE__, cpdd);
 
 							errno = 0;
-							if(munmap(rwd.buf[0], read_size) != 0)
+							if(munmap(buf[0], read_size) != 0)
 							{
 								print_error("munmap", __FILE__, __LINE__, cpdd);
 							}
 
 							goto LOOP_END;
 						}
-						tmp += rwd.written_size[0];
-						rwd.total_write_local += rwd.written_size[0];
+						tmp += written_size[0];
+						total_write_local += written_size[0];
 					}
 
 					errno = 0;
-					if(munmap(rwd.buf[0], read_size) != 0)
+					if(munmap(buf[0], read_size) != 0)
 					{
 						print_error("munmap", __FILE__, __LINE__, cpdd);
 					}
@@ -367,7 +413,7 @@ _Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 					break;
 				}
 
-				if(rwd.total_read_local >= rwd.from_size_local)
+				if(total_read_local >= from_size_local)
 				{
 					break;
 				}
@@ -386,7 +432,7 @@ LOOP_END:
 		 * openしたときにposix_fallocate、ftruncate、pwriteのいずれかを、
 		 * 必ず行うようにしたが、念のためここの処理も残しておくべき。
 		*/
-		if(ftruncate(rwd.ito, rwd.from_size_local) == -1)
+		if(ftruncate(ito, from_size_local) == -1)
 		{
 			print_error("ftruncate", __FILE__, __LINE__, cpdd);
 		}
@@ -394,7 +440,7 @@ LOOP_END:
 
 	if(from_open == true)
 	{
-		if(close(rwd.ifrom) == -1)
+		if(close(ifrom) == -1)
 		{
 			print_error("close", __FILE__, __LINE__, cpdd);
 		}
@@ -402,7 +448,7 @@ LOOP_END:
 
 	if(to_open == true)
 	{
-		if(close(rwd.ito) == -1)
+		if(close(ito) == -1)
 		{
 			print_error("close", __FILE__, __LINE__, cpdd);
 		}
@@ -413,48 +459,43 @@ LOOP_END:
 		ch_time_and_mod(&stat_buf, cpinfo, cpdd);
 	}
 
-	if(rwd.total_read_local > 0)
+	if(total_read_local > 0)
 	{
-		cpinfo->from_size = rwd.from_size_local;
-		cpdd->total_read += rwd.total_read_local;
+		cpinfo->from_size = from_size_local;
+		cpdd->total_read += total_read_local;
 	}
 
-	if(rwd.total_write_local > 0)
+	if(total_write_local > 0)
 	{
-		cpinfo->to_size = rwd.total_write_local;
-		cpdd->total_write += rwd.total_write_local;
+		cpinfo->to_size = total_write_local;
+		cpdd->total_write += total_write_local;
 	}
 
-	if(rwd.total_read_error > 0)
+	if(total_read_error > 0)
 	{
-		cpdd->total_error += rwd.total_read_error;
+		cpdd->total_error += total_read_error;
 	}
 
-	if(rwd.total_write_error > 0)
+	if(total_write_error > 0)
 	{
-		cpdd->total_error += rwd.total_write_error;
+		cpdd->total_error += total_write_error;
 	}
 
 	write_now = NULL;
 
-	if(oparg->compare_mode == 1)
+	if(oparg->COMPARE_MODE == BEFORE)
 	{
+		switch(oparg->C)
+		{
+		case ONE:
+			HASH_CHECK
+			break;
 
-		if((oparg->C == ONE) || (oparg->C == FIVE))
-		{
-			if((from_open == true) && (to_open == true))
-			{
-				compare_hash(oparg, cpinfo, sdir, cpdd);
-			}
-			else
-			{
-				fprintf(stderr, "ファイルのオープンに失敗しているため、コンペアをスキップします\n");
-				fprintf(stderr, "from : %s\n", cpinfo->from);
-				fprintf(stderr, "to   : %s\n", cpinfo->to);
-			}
-		}
-		else if((oparg->C == COMPARE))
-		{
+		case FIVE:
+			HASH_CHECK
+			break;
+
+		case MEMCMP:
 			if((cpinfo->from_size > 0) && (cpinfo->to_size > 0))
 			{
 				compare_memcmp(oparg, cpinfo, sdir, cpdd);
@@ -465,13 +506,17 @@ LOOP_END:
 				fprintf(stderr, "from : %s\n", cpinfo->from);
 				fprintf(stderr, "to   : %s\n", cpinfo->to);
 			}
-		}
-		else
-		{
-			puts("コンペアオプションが不正です");
+			break;
+
+		default:
+			fprintf(stderr, "コンペアオプションが不正です");
+			break;
 		}
 
-		puts("");
+		if(oparg->V == VERBOS)
+		{
+			puts("");
+		}
 	}
 
 	if((from_open == true) && (to_open == true))
@@ -485,28 +530,27 @@ LOOP_END:
 }
 
 /*******************************************************************************
- * 読み取り関数。pthreadで使うので仮引数はvoid *。
+ * 読み取り関数。引数は使用しない。
 *******************************************************************************/
-static void * read_thread(void *read_t)
+static void * read_thread(void *unknown)
 {
-	RWD *rwd = (RWD *)read_t;
-	int i = rwd->rbuf_num;
+	int i = rbuf_num;
 
-	if(rwd->from_size_local <= rwd->total_read_local)
+	if(from_size_local <= total_read_local)
 	{
-		rwd->next_write_size[i] = 0;
+		next_write_size[i] = 0;
 		return NULL;
 	}
 
-	off_t read_size = rwd->from_size_local - rwd->total_read_local;
+	off_t read_size = from_size_local - total_read_local;
 
-	if(read_size >= rwd->buffer_size_local)
+	if(read_size >= buffer_size_local)
 	{
-		read_size = rwd->buffer_size_local;
+		read_size = buffer_size_local;
 	}
 	else
 	{
-		off_t tmp = read_size % rwd->psize;
+		off_t tmp = read_size % psize;
 		if(tmp != read_size)
 		{
 			read_size = read_size - tmp;
@@ -514,74 +558,73 @@ static void * read_thread(void *read_t)
 	}
 
 	errno = 0;
-	rwd->buf[i] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, rwd->ifrom, rwd->total_read_local);
-	if(rwd->buf[i] != MAP_FAILED)
+	buf[i] = mmap(NULL, read_size, PROT_READ, MAP_PRIVATE, ifrom, total_read_local);
+	if(buf[i] != MAP_FAILED)
 	{
 		errno = 0;
 		/*
 		 * マルチスレッドの場合、
 		 * MADV_SEQUENTIALよりもMADV_WILLNEEDの方が速い、ような気がする。
 		*/
-		if(madvise(rwd->buf[i], read_size, MADV_WILLNEED) != 0)
+		if(madvise(buf[i], read_size, MADV_WILLNEED) != 0)
 		{
 			// このcpddに意味はない。print_errorの引数用。
 			CPDD cpdd;
 			cpdd.total_error = 0;
 			print_error("madvise", __FILE__, __LINE__, &cpdd);
-			rwd->total_read_error++;
+			total_read_error++;
 		}
 
-		rwd->total_read_local += read_size;
-		rwd->next_write_size[i] = read_size;
+		total_read_local += read_size;
+		next_write_size[i] = read_size;
 	}
 	else
 	{
-		rwd->next_write_size[i] = 0;
+		next_write_size[i] = 0;
 	}
 
 	return NULL;
 }
 
 /*******************************************************************************
- * 書き込み関数。pthreadで使うので仮引数はvoid *。
+ * 書き込み関数。引数は使用しない。
 *******************************************************************************/
-static void * write_thread(void *write_t)
+static void * write_thread(void *unknown)
 {
-	RWD *rwd = (RWD *)write_t;
-	int i = rwd->wbuf_num;
-	char *tmp = (char *)rwd->buf[i];
-	const char * const endp = tmp + rwd->next_write_size[i];
+	int i = wbuf_num;
+	char *tmp = (char *)buf[i];
+	const char * const endp = tmp + next_write_size[i];
 
-	if(rwd->next_write_size[i] > 0)
+	if(next_write_size[i] > 0)
 	{
 		while(tmp < endp)
 		{
 			errno = 0;
-			if((rwd->written_size[i] = write(rwd->ito, tmp, endp - tmp)) == -1)
+			if((written_size[i] = write(ito, tmp, endp - tmp)) == -1)
 			{
 				// このcpddに意味はない。print_errorの引数用。
 				CPDD cpdd;
 				cpdd.total_error = 0;
 				print_error("write", __FILE__, __LINE__, &cpdd);
-				rwd->total_write_error++;
+				total_write_error++;
 				break;
 			}
-			tmp += rwd->written_size[i];
-			rwd->total_write_local += rwd->written_size[i];
+			tmp += written_size[i];
+			total_write_local += written_size[i];
 		}
 
 		errno = 0;
-		if(munmap(rwd->buf[i], rwd->next_write_size[i]) == -1)
+		if(munmap(buf[i], next_write_size[i]) == -1)
 		{
 			CPDD cpdd;
 			cpdd.total_error = 0;
 			print_error("munmap", __FILE__, __LINE__, &cpdd);
-			rwd->total_write_error++;
+			total_write_error++;
 		}
 	}
 	else
 	{
-		rwd->written_size[i] = 0;
+		written_size[i] = 0;
 	}
 
 	return NULL;
